==> blesta-5.10.2.zip: blesta/language/it_it/navigation.php <==
<?php
/**
 * Navigation
 *
 * @package blesta
 * @subpackage blesta.language.it_it
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Navigation.getprimary.nav_tools_blacklist'] = 'Lista nera';
$lang['Navigation.getsearchoptions.packages'] = 'Ricerca per pacchetto';
$lang['Navigation.getsearchoptions.services'] = 'Ricerca di servizio';
$lang['Navigation.getsearchoptions.transactions'] = 'Ricerca per transazione';
$lang['Navigation.getsearchoptions.invoices'] = 'Ricerca fatture';
$lang['Navigation.getsearchoptions.clients'] = 'Ricerca clienti';
$lang['Navigation.getsearchoptions.smart'] = 'Ricerca intelligente';
$lang['Navigation.getsystem.nav_marketplace'] = 'Mercato';
$lang['Navigation.getsystem.nav_help_about'] = 'Informazioni su Blesta';
$lang['Navigation.getsystem.nav_help_notes'] = 'Note di rilascio';
$lang['Navigation.getsystem.nav_help_index'] = 'Risorse';
$lang['Navigation.getsystem.nav_help'] = 'Aiuto';
$lang['Navigation.getsystem.nav_upgrade'] = 'Opzioni di aggiornamento';
$lang['Navigation.getsystem.nav_api'] = 'Accesso API';
$lang['Navigation.getsystem.nav_staff_groups'] = 'Gruppi di lavoro';
$lang['Navigation.getsystem.nav_staff_manage'] = 'Gestire il personale';
$lang['Navigation.getsystem.nav_staff'] = 'Personale';
$lang['Navigation.getsystem.nav_backup_amazon'] = 'Amazon S3';
$lang['Navigation.getsystem.nav_backup_index'] = 'Su richiesta';
$lang['Navigation.getsystem.nav_backup_ftp'] = 'FTP sicuro';
$lang['Navigation.getsystem.nav_backup'] = 'Backup';
$lang['Navigation.getsystem.nav_companies'] = 'Aziende';
$lang['Navigation.getsystem.nav_automation'] = 'Automazione';
$lang['Navigation.getsystem.nav_general_paymenttypes'] = 'Tipi di pagamento';
$lang['Navigation.getsystem.nav_general_license'] = 'Chiave di licenza';
$lang['Navigation.getsystem.nav_general_maintenance'] = 'Manutenzione';
$lang['Navigation.getsystem.nav_general_geoip'] = 'Impostazioni GeoIP';
$lang['Navigation.getsystem.nav_general_basic'] = 'Impostazione di base';
$lang['Navigation.getsystem.nav_general'] = 'Generale';
$lang['Navigation.getcompany.nav_feeds_settings'] = 'Impostazioni di alimentazione';
$lang['Navigation.getcompany.nav_feeds_general'] = 'Generale';
$lang['Navigation.getcompany.nav_feeds'] = 'Feed di dati';
$lang['Navigation.getcompany.nav_groups'] = 'Gruppi di clienti';
$lang['Navigation.getcompany.nav_plugins'] = 'Plugin';
$lang['Navigation.getcompany.nav_currency_active'] = 'Valute attive';
$lang['Navigation.getcompany.nav_currency_currencysetup'] = 'Impostazione della valuta';
$lang['Navigation.getcompany.nav_currencies'] = 'Valute';
$lang['Navigation.getcompany.nav_clientoptions_requiredfields'] = 'Campi obbligatori del cliente';
$lang['Navigation.getcompany.nav_clientoptions_customfields'] = 'Campi personalizzati del cliente';
$lang['Navigation.getcompany.nav_clientoptions_general'] = 'Impostazioni generali del client';
$lang['Navigation.getcompany.nav_clientoptions'] = 'Opzioni del cliente';
$lang['Navigation.getcompany.nav_emails_signatures'] = 'Firme';
$lang['Navigation.getcompany.nav_emails_templates'] = 'Modelli di e-mail';
$lang['Navigation.getcompany.nav_emails_mail'] = 'Impostazioni della posta';
$lang['Navigation.getcompany.nav_emails'] = 'Email';
$lang['Navigation.getcompany.nav_taxes_taxrules'] = 'Regole fiscali';
$lang['Navigation.getcompany.nav_taxes_basictax'] = 'Impostazioni fiscali di base';
$lang['Navigation.getcompany.nav_taxes'] = 'Tasse';
$lang['Navigation.getcompany.nav_gateways'] = 'Gateway di pagamento';
$lang['Navigation.getcompany.nav_messengers_templates'] = 'Modelli di messaggio';
$lang['Navigation.getcompany.nav_messengers_configuration'] = 'Configurazione del messaggero';
$lang['Navigation.getcompany.nav_messengers_messengers'] = 'Messaggeri';
$lang['Navigation.getcompany.nav_messengers'] = 'Messaggeri';
$lang['Navigation.getcompany.nav_modules'] = 'Moduli';
$lang['Navigation.getcompany.nav_billing_acceptedtypes'] = 'Tipi di pagamento accettati';
$lang['Navigation.getcompany.nav_billing_coupons'] = 'Buoni sconto';
$lang['Navigation.getcompany.nav_billing_notices'] = 'Avvisi';
$lang['Navigation.getcompany.nav_billing_latefees'] = 'Tasse di mora';
$lang['Navigation.getcompany.nav_billing_deliverymethods'] = 'Consegna della fattura';
$lang['Navigation.getcompany.nav_billing_custominvoice'] = 'Personalizzazione della fattura';
$lang['Navigation.getcompany.nav_billing_invoices'] = 'Opzioni di fatturazione e addebito';
$lang['Navigation.getcompany.nav_billing'] = 'Fatturazione/Pagamento';
$lang['Navigation.getcompany.nav_automation'] = 'Automazione';
$lang['Navigation.getcompany.nav_lookandfeel_customize'] = 'Personalizzare';
$lang['Navigation.getcompany.nav_lookandfeel_actions'] = 'Azioni';
$lang['Navigation.getcompany.nav_lookandfeel_navigation'] = 'Navigazione';
$lang['Navigation.getcompany.nav_lookandfeel_layout'] = 'Layout';
$lang['Navigation.getcompany.nav_lookandfeel_template'] = 'Modello';
$lang['Navigation.getcompany.nav_lookandfeel_themes'] = 'Temi';
$lang['Navigation.getcompany.nav_lookandfeel'] = 'Look and Feel';
$lang['Navigation.getcompany.nav_general_humanverification'] = 'Verifica umana';
$lang['Navigation.getcompany.nav_general_smart_search'] = 'Ricerca intelligente';
$lang['Navigation.getcompany.nav_general_marketing'] = 'Marketing';
$lang['Navigation.getcompany.nav_general_contacttypes'] = 'Tipi di contatto';
$lang['Navigation.getcompany.nav_general_encryption'] = 'Crittografia';
$lang['Navigation.getcompany.nav_general_international'] = 'Internazionalizzazione';
$lang['Navigation.getcompany.nav_general_localization'] = 'Localizzazione';
$lang['Navigation.getcompany.nav_general'] = 'Generale';
$lang['Navigation.getprimarypublic.nav_dashboard'] = 'Casa';
$lang['Navigation.getprimaryclient.nav_return'] = 'Ritorno al cruscotto';
$lang['Navigation.getprimaryclient.nav_contacts_add'] = 'Aggiungi contatto';
$lang['Navigation.getprimaryclient.nav_contacts'] = 'Contatti';
$lang['Navigation.getprimaryclient.nav_paymentaccounts_add'] = 'Aggiungi conto di pagamento';
$lang['Navigation.getprimaryclient.nav_paymentaccounts'] = 'Conti di pagamento';
$lang['Navigation.getprimaryclient.nav_services'] = 'Servizi';
$lang['Navigation.getprimaryclient.nav_dashboard'] = 'Cruscotto';
$lang['Navigation.getprimary.nav_settings_system'] = 'Sistema';
$lang['Navigation.getprimary.nav_settings_company'] = 'Azienda';
$lang['Navigation.getprimary.nav_tools_renewals'] = 'Coda di rinnovo';
$lang['Navigation.getprimary.nav_tools_utilities'] = 'Utilità';
$lang['Navigation.getprimary.nav_tools_currency'] = 'Convertire la valuta';
$lang['Navigation.getprimary.nav_tools_logs'] = 'Registri';
$lang['Navigation.getprimary.nav_tools'] = 'Strumenti';
$lang['Navigation.getprimary.nav_package_options'] = 'Opzioni configurabili';
$lang['Navigation.getprimary.nav_packages_groups'] = 'Gruppi di pacchetti';
$lang['Navigation.getprimary.nav_packages_browse'] = 'Sfoglia i pacchetti';
$lang['Navigation.getprimary.nav_packages'] = 'Pacchetti';
$lang['Navigation.getprimary.nav_billing_batch'] = 'Lotto';
$lang['Navigation.getprimary.nav_billing_printqueue'] = 'Coda di stampa';
$lang['Navigation.getprimary.nav_billing_reports'] = 'Rapporti';
$lang['Navigation.getprimary.nav_billing_services'] = 'Servizi';
$lang['Navigation.getprimary.nav_billing_transactions'] = 'Transazioni';
$lang['Navigation.getprimary.nav_billing_quotations'] = 'Citazioni';
$lang['Navigation.getprimary.nav_billing_invoices'] = 'Fatture';
$lang['Navigation.getprimary.nav_billing_overview'] = 'Panoramica';
$lang['Navigation.getprimary.nav_billing'] = 'Fatturazione';
$lang['Navigation.getprimary.nav_clients_browse'] = 'Sfoglia i clienti';
$lang['Navigation.getprimary.nav_clients'] = 'Clienti';
$lang['Navigation.getprimary.nav_home_dashboard'] = 'Cruscotto';
$lang['Navigation.getprimary.nav_home'] = 'Casa';
$lang['Navigation.!error.parent_id.valid'] = 'ID elemento di navigazione genitore non valido';
$lang['Navigation.!error.order.valid'] = 'L\'indice dell\'ordine deve essere un valore numerico';
$lang['Navigation.!error.action_id.valid'] = 'ID azione non valido';

==> blesta-5.11.4.zip: blesta/language/it_it/navigation.php <==
<?php
/**
 * Navigation
 *
 * @package blesta
 * @subpackage blesta.language.it_it
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Navigation.getprimary.nav_tools_blacklist'] = 'Lista nera';
$lang['Navigation.getsearchoptions.packages'] = 'Ricerca per pacchetto';
$lang['Navigation.getsearchoptions.services'] = 'Ricerca di servizio';
$lang['Navigation.getsearchoptions.transactions'] = 'Ricerca per transazione';
$lang['Navigation.getsearchoptions.invoices'] = 'Ricerca fatture';
$lang['Navigation.getsearchoptions.clients'] = 'Ricerca clienti';
$lang['Navigation.getsearchoptions.smart'] = 'Ricerca intelligente';
$lang['Navigation.getsystem.nav_marketplace'] = 'Mercato';
$lang['Navigation.getsystem.nav_help_about'] = 'Informazioni su Blesta';
$lang['Navigation.getsystem.nav_help_notes'] = 'Note di rilascio';
$lang['Navigation.getsystem.nav_help_index'] = 'Risorse';
$lang['Navigation.getsystem.nav_help'] = 'Aiuto';
$lang['Navigation.getsystem.nav_upgrade'] = 'Opzioni di aggiornamento';
$lang['Navigation.getsystem.nav_api'] = 'Accesso API';
$lang['Navigation.getsystem.nav_staff_groups'] = 'Gruppi di lavoro';
$lang['Navigation.getsystem.nav_staff_manage'] = 'Gestire il personale';
$lang['Navigation.getsystem.nav_staff'] = 'Personale';
$lang['Navigation.getsystem.nav_backup_amazon'] = 'Amazon S3';
$lang['Navigation.getsystem.nav_backup_index'] = 'Su richiesta';
$lang['Navigation.getsystem.nav_backup_ftp'] = 'FTP sicuro';
$lang['Navigation.getsystem.nav_backup'] = 'Backup';
$lang['Navigation.getsystem.nav_companies'] = 'Aziende';
$lang['Navigation.getsystem.nav_automation'] = 'Automazione';
$lang['Navigation.getsystem.nav_general_paymenttypes'] = 'Tipi di pagamento';
$lang['Navigation.getsystem.nav_general_license'] = 'Chiave di licenza';
$lang['Navigation.getsystem.nav_general_maintenance'] = 'Manutenzione';
$lang['Navigation.getsystem.nav_general_geoip'] = 'Impostazioni GeoIP';
$lang['Navigation.getsystem.nav_general_basic'] = 'Impostazione di base';
$lang['Navigation.getsystem.nav_general'] = 'Generale';
$lang['Navigation.getcompany.nav_feeds_settings'] = 'Impostazioni di alimentazione';
$lang['Navigation.getcompany.nav_feeds_general'] = 'Generale';
$lang['Navigation.getcompany.nav_feeds'] = 'Feed di dati';
$lang['Navigation.getcompany.nav_groups'] = 'Gruppi di clienti';
$lang['Navigation.getcompany.nav_plugins'] = 'Plugin';
$lang['Navigation.getcompany.nav_currency_active'] = 'Valute attive';
$lang['Navigation.getcompany.nav_currency_currencysetup'] = 'Impostazione della valuta';
$lang['Navigation.getcompany.nav_currencies'] = 'Valute';
$lang['Navigation.getcompany.nav_clientoptions_requiredfields'] = 'Campi obbligatori del cliente';
$lang['Navigation.getcompany.nav_clientoptions_customfields'] = 'Campi personalizzati del cliente';
$lang['Navigation.getcompany.nav_clientoptions_general'] = 'Impostazioni generali del client';
$lang['Navigation.getcompany.nav_clientoptions'] = 'Opzioni del cliente';
$lang['Navigation.getcompany.nav_emails_signatures'] = 'Firme';
$lang['Navigation.getcompany.nav_emails_templates'] = 'Modelli di e-mail';
$lang['Navigation.getcompany.nav_emails_mail'] = 'Impostazioni della posta';
$lang['Navigation.getcompany.nav_emails'] = 'Email';
$lang['Navigation.getcompany.nav_taxes_taxrules'] = 'Regole fiscali';
$lang['Navigation.getcompany.nav_taxes_basictax'] = 'Impostazioni fiscali di base';
$lang['Navigation.getcompany.nav_taxes'] = 'Tasse';
$lang['Navigation.getcompany.nav_gateways'] = 'Gateway di pagamento';
$lang['Navigation.getcompany.nav_messengers_templates'] = 'Modelli di messaggio';
$lang['Navigation.getcompany.nav_messengers_configuration'] = 'Configurazione del messaggero';
$lang['Navigation.getcompany.nav_messengers_messengers'] = 'Messaggeri';
$lang['Navigation.getcompany.nav_messengers'] = 'Messaggeri';
$lang['Navigation.getcompany.nav_modules'] = 'Moduli';
$lang['Navigation.getcompany.nav_billing_acceptedtypes'] = 'Tipi di pagamento accettati';
$lang['Navigation.getcompany.nav_billing_coupons'] = 'Buoni sconto';
$lang['Navigation.getcompany.nav_billing_notices'] = 'Avvisi';
$lang['Navigation.getcompany.nav_billing_latefees'] = 'Tasse di mora';
$lang['Navigation.getcompany.nav_billing_deliverymethods'] = 'Consegna della fattura';
$lang['Navigation.getcompany.nav_billing_custominvoice'] = 'Personalizzazione della fattura';
$lang['Navigation.getcompany.nav_billing_invoices'] = 'Opzioni di fatturazione e addebito';
$lang['Navigation.getcompany.nav_billing'] = 'Fatturazione/Pagamento';
$lang['Navigation.getcompany.nav_automation'] = 'Automazione';
$lang['Navigation.getcompany.nav_lookandfeel_customize'] = 'Personalizzare';
$lang['Navigation.getcompany.nav_lookandfeel_actions'] = 'Azioni';
$lang['Navigation.getcompany.nav_lookandfeel_navigation'] = 'Navigazione';
$lang['Navigation.getcompany.nav_lookandfeel_layout'] = 'Layout';
$lang['Navigation.getcompany.nav_lookandfeel_template'] = 'Modello';
$lang['Navigation.getcompany.nav_lookandfeel_themes'] = 'Temi';
$lang['Navigation.getcompany.nav_lookandfeel'] = 'Look and Feel';
$lang['Navigation.getcompany.nav_general_humanverification'] = 'Verifica umana';
$lang['Navigation.getcompany.nav_general_smart_search'] = 'Ricerca intelligente';
$lang['Navigation.getcompany.nav_general_marketing'] = 'Marketing';
$lang['Navigation.getcompany.nav_general_contacttypes'] = 'Tipi di contatto';
$lang['Navigation.getcompany.nav_general_encryption'] = 'Crittografia';
$lang['Navigation.getcompany.nav_general_international'] = 'Internazionalizzazione';
$lang['Navigation.getcompany.nav_general_localization'] = 'Localizzazione';
$lang['Navigation.getcompany.nav_general'] = 'Generale';
$lang['Navigation.getprimarypublic.nav_dashboard'] = 'Casa';
$lang['Navigation.getprimaryclient.nav_return'] = 'Ritorno al cruscotto';
$lang['Navigation.getprimaryclient.nav_contacts_add'] = 'Aggiungi contatto';
$lang['Navigation.getprimaryclient.nav_contacts'] = 'Contatti';
$lang['Navigation.getprimaryclient.nav_paymentaccounts_add'] = 'Aggiungi conto di pagamento';
$lang['Navigation.getprimaryclient.nav_paymentaccounts'] = 'Conti di pagamento';
$lang['Navigation.getprimaryclient.nav_services'] = 'Servizi';
$lang['Navigation.getprimaryclient.nav_dashboard'] = 'Cruscotto';
$lang['Navigation.getprimary.nav_settings_system'] = 'Sistema';
$lang['Navigation.getprimary.nav_settings_company'] = 'Azienda';
$lang['Navigation.getprimary.nav_tools_renewals'] = 'Coda di rinnovo';
$lang['Navigation.getprimary.nav_tools_utilities'] = 'Utilità';
$lang['Navigation.getprimary.nav_tools_currency'] = 'Convertire la valuta';
$lang['Navigation.getprimary.nav_tools_logs'] = 'Registri';
$lang['Navigation.getprimary.nav_tools'] = 'Strumenti';
$lang['Navigation.getprimary.nav_package_options'] = 'Opzioni configurabili';
$lang['Navigation.getprimary.nav_packages_groups'] = 'Gruppi di pacchetti';
$lang['Navigation.getprimary.nav_packages_browse'] = 'Sfoglia i pacchetti';
$lang['Navigation.getprimary.nav_packages'] = 'Pacchetti';
$lang['Navigation.getprimary.nav_billing_batch'] = 'Lotto';
$lang['Navigation.getprimary.nav_billing_printqueue'] = 'Coda di stampa';
$lang['Navigation.getprimary.nav_billing_reports'] = 'Rapporti';
$lang['Navigation.getprimary.nav_billing_services'] = 'Servizi';
$lang['Navigation.getprimary.nav_billing_transactions'] = 'Transazioni';
$lang['Navigation.getprimary.nav_billing_quotations'] = 'Citazioni';
$lang['Navigation.getprimary.nav_billing_invoices'] = 'Fatture';
$lang['Navigation.getprimary.nav_billing_overview'] = 'Panoramica';
$lang['Navigation.getprimary.nav_billing'] = 'Fatturazione';
$lang['Navigation.getprimary.nav_clients_browse'] = 'Sfoglia i clienti';
$lang['Navigation.getprimary.nav_clients'] = 'Clienti';
$lang['Navigation.getprimary.nav_home_dashboard'] = 'Cruscotto';
$lang['Navigation.getprimary.nav_home'] = 'Casa';
$lang['Navigation.!error.parent_id.valid'] = 'ID elemento di navigazione genitore non valido';
$lang['Navigation.!error.order.valid'] = 'L\'indice dell\'ordine deve essere un valore numerico';
$lang['Navigation.!error.action_id.valid'] = 'ID azione non valido';
$lang['Navigation.getcompany.nav_html_templates'] = 'Modelli HTML';
$lang['Navigation.getprimary.nav_tools_provisioning'] = 'Coda di servizio';
